@@ -230,7 +230,7 @@ fallback_shape (PangoEngineShape *engine,
 		PangoFont        *font,
 		const char       *text,
 		gint              length,
-		PangoAnalysis    *analysis,
+		const PangoAnalysis *analysis,
 		PangoGlyphString *glyphs)
 {
   const char *p;
@@ -292,7 +292,7 @@ hebrew_engine_shape (PangoEngineShape *engine,
 		     PangoFont        *font,
 		     const char       *text,
 		     gint              length,
-		     PangoAnalysis    *analysis,
+		     const PangoAnalysis *analysis,
 		     PangoGlyphString *glyphs)
 {
   PangoFcFont *fc_font;
@@ -312,7 +312,8 @@ hebrew_engine_shape (PangoEngineShape *engine,
 
   fc_font = PANGO_FC_FONT (font);
   face = pango_fc_font_lock_face (fc_font);
-  g_return_if_fail (face != NULL);
+  if (!face)
+    return;
 
   ruleset = get_ruleset (face);
   if (!ruleset)
